@@ -475,6 +475,7 @@ class GradebookOverview(SectionFinder, JSONScoresBase):
     """Gradebook Overview/Table"""
 
     isTeacher = True
+    needs_comments = False
 
     @Lazy
     def students_info(self):
@@ -649,6 +650,7 @@ class GradebookOverview(SectionFinder, JSONScoresBase):
             updateGrades = ''
 
         if ICommentScoreSystem.providedBy(insecure_activity.scoresystem):
+            self.needs_comments = True
             zc.resourcelibrary.need("fckeditor")
 
         return {
@@ -1273,7 +1275,7 @@ class GradeActivity(object):
                    'value': value}
 
     def doneURL(self):
-        return absoluteURL(ISection(self.context), self.request)
+        return absoluteURL(self.context, self.request)
 
     def update(self):
         self.messages = []
@@ -1318,7 +1320,7 @@ class GradeActivity(object):
                             student, activity, request_score_value, evaluator)
 
             if not len(self.messages):
-                self.request.response.redirect('index.html')
+                self.request.response.redirect(self.doneURL())
 
 
 class FlourishGradeActivity(GradeActivity, flourish.page.Page):
